@@ -6,7 +6,7 @@ package SQLRelay::Connection;
 require DynaLoader;
 @ISA = 'DynaLoader';
 
-$VERSION = '0.35';
+$VERSION = '0.38';
 
 bootstrap SQLRelay::Connection $VERSION;
 
@@ -70,12 +70,16 @@ __END__
             # communicating over. This parameter may be 
             # passed to another client for use in
             # the resumeSession() command below.
+            # Note: the value returned by this method is
+            # only valid after a call to suspendSession().
 
         getConnectionSocket();
             # Returns the unix socket that the client is 
             # communicating over. This parameter may be 
             # passed to another client for use in
             # the resumeSession() command below.
+            # Note: the value returned by this method is
+            # only valid after a call to suspendSession().
 
         resumeSession(port,socket);
             # Resumes a session previously left open 
@@ -128,6 +132,6 @@ __END__
 =head1 AUTHOR
 
     David Muse
-    dmuse@firstworks.com
+    david.muse@firstworks.com
 
 =cut
