@@ -6,7 +6,7 @@ package SQLRelay::Cursor;
 require DynaLoader;
 @ISA = 'DynaLoader';
 
-$VERSION = '0.35';
+$VERSION = '0.38';
 
 bootstrap SQLRelay::Cursor $VERSION;
 
@@ -232,7 +232,7 @@ __END__
         inputBindClob(variable,value,size);
             # Define an input bind variable.
 
-        defineOutputBind(variable,bufferlength);
+        defineOutputBindString(variable,bufferlength);
             # Define an output bind variable.
             # "bufferlength" bytes will be reserved to store the value.
         defineOutputBindBlob(variable);
@@ -264,7 +264,15 @@ __END__
             # an output bind variable.
 
 
-	getOutputBind(variable);
+	getOutputBindString(variable);
+            # Get the value stored in a previously
+            # defined output bind variable.
+
+	getOutputBindBlob(variable);
+            # Get the value stored in a previously
+            # defined output bind variable.
+
+	getOutputBindClob(variable);
             # Get the value stored in a previously
             # defined output bind variable.
 
@@ -434,12 +442,6 @@ __END__
             # Returns the length of the longest field
             # in the specified column.
 
-        getResultSetId();
-            # Returns the internal ID of this result set.
-            # This parameter may be passed to another 
-            # statement for use in the resumeResultSet() 
-            # method.
-
         suspendResultSet();
             # Tells the server to leave this result
             # set open when the client calls 
@@ -447,6 +449,14 @@ __END__
             # connect to it using resumeResultSet() after 
             # it calls resumeSession().
 
+        getResultSetId();
+            # Returns the internal ID of this result set.
+            # This parameter may be passed to another 
+            # statement for use in the resumeResultSet() 
+            # method.
+            # Note: the value returned by this method is
+            # only valid after a call to suspendResultSet().
+
         resumeResultSet(int id);
             # Resumes a result set previously left open 
             # using suspendSession().
@@ -461,6 +471,6 @@ __END__
 =head1 AUTHOR
 
     David Muse
-    dmuse@firstworks.com
+    david.muse@firstworks.com
 
 =cut
