@@ -72,6 +72,31 @@
 
 #define MAXCONNECTIONIDLEN 1024
 
+#define NOCURSORSERROR "No server-side cursors were available to process the query."
+
+struct sqlrstatistics {
+	int32_t	open_svr_connections;
+	int32_t	opened_svr_connections;
+
+	int32_t	open_cli_connections;
+	int32_t	opened_cli_connections;
+
+//	int32_t	timed_out_svr_connections;
+//	int32_t	timed_out_cli_connections;
+	
+	int32_t	open_svr_cursors;
+	int32_t	opened_svr_cursors;
+
+	int32_t	times_new_cursor_used;
+	int32_t	times_cursor_reused;
+
+	int32_t	total_queries;
+	int32_t	total_errors;
+
+	int32_t	forked_listeners;
+};
+
+
 // This structure is used to pass data in shared memory between the listener
 // and connection daemons.  A struct is used instead of just stepping a pointer
 // through the shared memory segment to avoid alignment issues.
@@ -86,6 +111,7 @@ struct shmdata {
 		} sockets;
 		pid_t	connectionpid;
 	} connectioninfo;
+	sqlrstatistics	statistics;
 };
 
 #endif
