@@ -11,7 +11,6 @@
 
 #define NUM_CONNECT_STRING_VARS	6
 
-#include <rudiments/environment.h>
 #include <sqlrconnection.h>
 
 #include <config.h>
@@ -162,7 +161,7 @@ class oracle7connection : public sqlrconnection_svr {
 	private:
 		uint16_t	getNumberOfConnectStringVars();
 		void		handleConnectString();
-		bool		logIn();
+		bool		logIn(bool printerrors);
 		sqlrcursor_svr	*initCursor();
 		void		deleteCursor(sqlrcursor_svr *curs);
 		void		logOut();
@@ -179,8 +178,6 @@ class oracle7connection : public sqlrconnection_svr {
 		const char	*home;
 		const char	*sid;
 		const char	*nlslang;
-
-		environment	*env;
 };
 
 #endif
