@@ -14,7 +14,6 @@
 #ifdef HAVE_ORACLE_8i
 	#include <rudiments/regularexpression.h>
 #endif
-#include <rudiments/environment.h>
 
 extern "C" {
 	#ifdef __CYGWIN__
@@ -42,7 +41,10 @@ extern "C" {
 
 struct describe {
 	OCIParam	*paramd;
-	sb4		dbsize;
+	// Hmm, oracle's docs say to use a ub4 for dbsize but it doesn't work...
+	// I had used an sb4 before and it worked in the past, but not on
+	// x86_64.
+	ub2		dbsize;
 	sb2		dbtype;
 	text		*buf;
 	sb4		buflen;
@@ -208,7 +210,7 @@ class oracle8connection : public sqlrconnection_svr {
 	private:
 		uint16_t	getNumberOfConnectStringVars();
 		void		handleConnectString();
-		bool		logIn();
+		bool		logIn(bool printerrors);
 		void		logInError(const char *errmsg);
 		sqlrcursor_svr	*initCursor();
 		void		deleteCursor(sqlrcursor_svr *curs);
@@ -245,8 +247,6 @@ class oracle8connection : public sqlrconnection_svr {
 		ub4		fetchatonce;
 		ub4		maxselectlistsize;
 		ub4		maxitembuffersize;
-
-		environment	*envr;
 };
 
 #endif
