@@ -21,10 +21,13 @@ class postgresqlcursor : public sqlrcursor_svr {
 	private:
 				postgresqlcursor(sqlrconnection_svr *conn);
 				~postgresqlcursor();
-#ifdef HAVE_POSTGRESQL_PQEXECPARAMS
+#ifdef HAVE_POSTGRESQL_PQEXECPREPARED
 		bool		openCursor(uint16_t id);
 		bool		prepareQuery(const char *query,
 						uint32_t length);
+#endif
+		bool		supportsNativeBinds();
+#ifdef HAVE_POSTGRESQL_PQEXECPREPARED
 		bool		inputBindString(const char *variable, 
 						uint16_t variablesize,
 						const char *value, 
@@ -76,7 +79,7 @@ class postgresqlcursor : public sqlrcursor_svr {
 
 		postgresqlconnection	*postgresqlconn;
 
-#ifdef HAVE_POSTGRESQL_PQEXECPARAMS
+#ifdef HAVE_POSTGRESQL_PQEXECPREPARED
 		bool		deallocatestatement;
 		int		bindcount;
 		int		bindcounter;
@@ -93,17 +96,13 @@ class postgresqlconnection : public sqlrconnection_svr {
 	friend class postgresqlcursor;
 	private:
 		uint16_t	getNumberOfConnectStringVars();
-		bool		supportsNativeBinds();
 		void		handleConnectString();
-		bool		logIn();
+		bool		logIn(bool printerrors);
 		sqlrcursor_svr	*initCursor();
 		void		deleteCursor(sqlrcursor_svr *curs);
 		void		logOut();
 		const char	*identify();
 
-		void		endSession();
-		void		dropTable(const char *table);
-
 		int	datatypecount;
 		int32_t	*datatypeids;
 		char	**datatypenames;
@@ -115,7 +114,7 @@ class postgresqlconnection : public sqlrconnection_svr {
 		const char	*options;
 		const char	*db;
 		uint16_t	typemangling;
-#ifdef HAVE_POSTGRESQL_PQEXECPARAMS
+#ifdef HAVE_POSTGRESQL_PQEXECPREPARED
 		bool		fakebinds;
 #endif
 
