@@ -7,6 +7,7 @@
 #define NUM_CONNECT_STRING_VARS 1
 
 #include <sqlrconnection.h>
+#include <rudiments/regularexpression.h>
 
 extern "C" {
 #ifdef SQLITE3
@@ -26,10 +27,12 @@ class sqlitecursor : public sqlrcursor_svr {
 	private:
 				sqlitecursor(sqlrconnection_svr *conn);
 				~sqlitecursor();
+		bool		supportsNativeBinds();
 		bool		executeQuery(const char *query,
 						uint32_t length,
 						bool execute);
 		int		runQuery(const char *query);
+		void		selectLastInsertRowId();
 		const char	*errorMessage(bool *liveconnection);
 		bool		knowsRowCount();
 		uint64_t	rowCount();
@@ -50,6 +53,9 @@ class sqlitecursor : public sqlrcursor_svr {
 		int		nrow;
 		int		ncolumn;
 		int		rowindex;
+		bool		lastinsertrowid;
+
+		regularexpression	selectlastinsertrowid;
 
 		sqliteconnection	*sqliteconn;
 };
@@ -60,9 +66,8 @@ class sqliteconnection : public sqlrconnection_svr {
 				sqliteconnection();
 	private:
 		uint16_t	getNumberOfConnectStringVars();
-		bool		supportsNativeBinds();
 		void		handleConnectString();
-		bool		logIn();
+		bool		logIn(bool printerrors);
 		sqlrcursor_svr	*initCursor();
 		void		deleteCursor(sqlrcursor_svr *curs);
 		void		logOut();
