@@ -60,7 +60,9 @@ typedef enum {
 	ROUTER_SOCKET_ATTRIBUTE,
 	ROUTER_USER_ATTRIBUTE,
 	ROUTER_PASSWORD_ATTRIBUTE,
-	ROUTER_PATTERN_ATTRIBUTE
+	ROUTER_PATTERN_ATTRIBUTE,
+	MAXLISTENERS_ATTRIBUTE,
+	LISTENERTIMEOUT_ATTRIBUTE
 } attribute;
 
 class usercontainer {
@@ -109,19 +111,20 @@ class connectstringcontainer {
 
 typedef linkedlistnode< connectstringcontainer * >	connectstringnode;
 
-class routercontainer {
+class routecontainer {
 	friend class sqlrconfigfile;
 	public:
-			routercontainer();
-			~routercontainer();
+			routecontainer();
+			~routecontainer();
 
+		void	setIsFilter(bool isfilter);
 		void	setHost(const char *host);
 		void	setPort(uint16_t port);
 		void	setSocket(const char *socket);
 		void	setUser(const char *user);
 		void	setPassword(const char *password);
-		// FIXME: methods for adding regular expressions
 
+		bool		getIsFilter();
 		const char	*getHost();
 		uint16_t	getPort();
 		const char	*getSocket();
@@ -129,6 +132,7 @@ class routercontainer {
 		const char	*getPassword();
 		linkedlist< regularexpression * >	*getRegexList();
 	private:
+		bool			isfilter;
 		char			*host;
 		uint16_t		port;
 		char			*socket;
@@ -137,7 +141,7 @@ class routercontainer {
 		linkedlist< regularexpression * >	regexlist;
 };
 
-typedef linkedlistnode< routercontainer * >	routernode;
+typedef linkedlistnode< routecontainer * >	routenode;
 
 class sqlrconfigfile : public xmlsax {
 	public:
@@ -180,6 +184,8 @@ class sqlrconfigfile : public xmlsax {
 		uint32_t	getMaxStringBindValueLength();
 		uint32_t	getMaxLobBindValueLength();
 		int32_t		getIdleClientTimeout();
+		int64_t		getMaxListeners();
+		uint32_t	getListenerTimeout();
 
 		bool		getSidEnabled();
 		const char	*getSidHost();
@@ -196,7 +202,7 @@ class sqlrconfigfile : public xmlsax {
 		uint32_t		getConnectionCount();
 		uint32_t		getMetricTotal();
 
-		linkedlist< routercontainer * >	*getRouterList();
+		linkedlist< routecontainer * >	*getRouteList();
 	private:
 		const char	*id;
 		bool		correctid;
@@ -206,15 +212,16 @@ class sqlrconfigfile : public xmlsax {
 		uint32_t	atouint32_t(const char *value,
 					const char *defaultvalue,
 					uint32_t minvalue);
-		uint16_t	atouint16_t(const char *value,
-					const char *defaultvalue,
-					uint16_t minvalue);
 
 		bool	tagStart(const char *name);
 		bool	attributeName(const char *name);
 		bool	attributeValue(const char *value);
 		bool	tagEnd(const char *name);
 
+		routecontainer	*routeAlreadyExists(routecontainer *cur);
+		void		moveRegexList(routecontainer *cur,
+						routecontainer *existing);
+
 		char		**addresses;
 		uint64_t	addresscount;
 		uint16_t	port;
@@ -248,6 +255,8 @@ class sqlrconfigfile : public xmlsax {
 		uint32_t	maxstringbindvaluelength;
 		uint32_t	maxlobbindvaluelength;
 		int32_t		idleclienttimeout;
+		int64_t		maxlisteners;
+		uint32_t	listenertimeout;
 
 		bool		sidenabled;
 		const char	*sidhost;
@@ -263,14 +272,15 @@ class sqlrconfigfile : public xmlsax {
 		uint32_t		connectioncount;
 		uint32_t		metrictotal;
 
-		routercontainer		*currentrouter;
+		routecontainer		*currentroute;
 		bool			inrouter;
+		bool			ignoreconnections;
 
 		uint16_t	connectstringcount;
 
 		linkedlist< connectstringcontainer * >	connectstringlist;
 		linkedlist< usercontainer * >		userlist;
-		linkedlist< routercontainer *>		routerlist;
+		linkedlist< routecontainer *>		routelist;
 };
 
 #endif
