@@ -50,26 +50,23 @@ void checkSuccessInt(int value, int success) {
 
 int	main(int argc, char **argv) {
 
-	const char	*dbtype;
-	char	*bindvars[11]={"1","2","3","4","5","6","7","8","9","10",NULL};
-	char	*bindvals[10]={"4","4","4","4.4","4.4","4.4",
+	const char	*bindvars[11]={"1","2","3","4","5","6",
+					"7","8","9","10",NULL};
+	const char	*bindvals[10]={"4","4","4","4.4","4.4","4.4",
 			"testchar4","testvarchar4","01/01/2004","04:00:00"};
-	char	*subvars[4]={"var1","var2","var3",NULL};
-	char	*subvalstrings[3]={"hi","hello","bye"};
-	long	subvallongs[3]={1,2,3};
-	double	subvaldoubles[3]={10.55,10.556,10.5556};
-	unsigned short	precs[3]={4,5,6};
-	unsigned short	scales[3]={2,3,4};
-	const char	*numvar;
-	const char	*stringvar;
-	const char	*floatvar;
+	const char	*subvars[4]={"var1","var2","var3",NULL};
+	const char	*subvalstrings[3]={"hi","hello","bye"};
+	int64_t		subvallongs[3]={1,2,3};
+	double		subvaldoubles[3]={10.55,10.556,10.5556};
+	uint32_t	precs[3]={4,5,6};
+	uint32_t	scales[3]={2,3,4};
 	const char * const *cols;
 	const char * const *fields;
-	int	port;
+	uint16_t	port;
 	const char	*socket;
-	int	id;
-	const char	*filename;
-	long	*fieldlens;
+	uint16_t	id;
+	char		*filename;
+	uint32_t	*fieldlens;
 
 	// usage...
 	if (argc<5) {
@@ -153,9 +150,9 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create procedure testproc(in invar int, out outvar int) language sql begin set outvar = invar; end"),1);
 	sqlrcur_prepareQuery(cur,"call testproc(?,?)");
 	sqlrcur_inputBindLong(cur,"1",5);
-	sqlrcur_defineOutputBind(cur,"2",10);
+	sqlrcur_defineOutputBindInteger(cur,"2");
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
-	checkSuccessString(sqlrcur_getOutputBind(cur,"2"),"5");
+	checkSuccessInt(sqlrcur_getOutputBindInteger(cur,"2"),5);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"drop procedure testproc"),1);
 	printf("\n");
 
@@ -271,7 +268,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("TOTAL ROWS: \n");
-	checkSuccessInt(sqlrcur_totalRows(cur),-1);
+	checkSuccessInt(sqlrcur_totalRows(cur),0);
 	printf("\n");
 
 	printf("FIRST ROW INDEX: \n");
@@ -751,4 +748,6 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
+
+	exit(0);
 }
