@@ -55,6 +55,32 @@ class oracle8i {
 		}
 	}
 	
+	private static void checkSuccess(byte[] value, String success, int length) {
+	
+		if (success==null) {
+			if (value==null) {
+				System.out.println("success ");
+				return;
+			} else {
+				System.out.println("failure ");
+				
+				
+				System.exit(0);
+			}
+		}
+
+		byte[]	successvalue=success.getBytes();
+	
+		for (int index=0; index<length; index++) {
+			if (value[index]!=successvalue[index]) {
+				System.out.println("failure ");
+				System.exit(0);
+			}
+		}
+
+		System.out.println("success ");
+	}
+	
 	private static void checkSuccess(long value, int success) {
 	
 		if (value==success) {
@@ -67,6 +93,18 @@ class oracle8i {
 		}
 	}
 	
+	private static void checkSuccess(double value, double success) {
+	
+		if (value==success) {
+			System.out.println("success ");
+		} else {
+			System.out.println("failure ");
+			
+			
+			System.exit(0);
+		}
+	}
+	
 	private static void checkSuccess(boolean value, int success) {
 	
 		if (((value)?1:0)==success) {
@@ -92,16 +130,16 @@ class oracle8i {
 		int[]	scales={2,3,4};
 		String	clobvar;
 		long	clobvarlength;
-		String	blobvar;
+		byte[]	blobvar;
 		long	blobvarlength;
-		String	numvar;
+		long	numvar;
 		String	stringvar;
-		String	floatvar;
+		double	floatvar;
 		String[]	cols;
 		String[]	fields;
-		int	port;
+		short	port;
 		String	socket;
-		int	id;
+		short	id;
 		String	filename;
 		String[]	arraybindvars={"var1","var2","var3","var4","var5"};
 		String[]	arraybindvals={"7","testchar7","testvarchar7","01-JAN-2007","testlong7"};
@@ -117,7 +155,7 @@ class oracle8i {
 	
 		// instantiation
 		SQLRConnection con=new SQLRConnection(args[0],
-                        Integer.parseInt(args[1]), 
+                        		(short)Integer.parseInt(args[1]), 
 						args[2],args[3],args[4],0,1);
 		SQLRCursor cur=new SQLRCursor(con);
 	
@@ -226,46 +264,46 @@ class oracle8i {
 	
 		System.out.println("OUTPUT BIND BY NAME: ");
 		cur.prepareQuery("begin  :numvar:=1; :stringvar:='hello'; :floatvar:=2.5; end;");
-		cur.defineOutputBind("numvar",10);
-		cur.defineOutputBind("stringvar",10);
-		cur.defineOutputBind("floatvar",10);
+		cur.defineOutputBindInteger("numvar");
+		cur.defineOutputBindString("stringvar",10);
+		cur.defineOutputBindDouble("floatvar");
 		checkSuccess(cur.executeQuery(),1);
-		numvar=cur.getOutputBind("numvar");
-		stringvar=cur.getOutputBind("stringvar");
-		floatvar=cur.getOutputBind("floatvar");
-		checkSuccess(numvar,"1");
+		numvar=cur.getOutputBindInteger("numvar");
+		stringvar=cur.getOutputBindString("stringvar");
+		floatvar=cur.getOutputBindDouble("floatvar");
+		checkSuccess(numvar,1);
 		checkSuccess(stringvar,"hello");
-		checkSuccess(floatvar,"2.5");
+		checkSuccess(floatvar,2.5);
 		System.out.println();
 	
-		System.out.println("OUTPUT BIND BY NAME: ");
+		System.out.println("OUTPUT BIND BY POSITION: ");
 		cur.clearBinds();
-		cur.defineOutputBind("1",10);
-		cur.defineOutputBind("2",10);
-		cur.defineOutputBind("3",10);
+		cur.defineOutputBindInteger("1");
+		cur.defineOutputBindString("2",10);
+		cur.defineOutputBindDouble("3");
 		checkSuccess(cur.executeQuery(),1);
-		numvar=cur.getOutputBind("1");
-		stringvar=cur.getOutputBind("2");
-		floatvar=cur.getOutputBind("3");
-		checkSuccess(numvar,"1");
+		numvar=cur.getOutputBindInteger("1");
+		stringvar=cur.getOutputBindString("2");
+		floatvar=cur.getOutputBindDouble("3");
+		checkSuccess(numvar,1);
 		checkSuccess(stringvar,"hello");
-		checkSuccess(floatvar,"2.5");
+		checkSuccess(floatvar,2.5);
 		System.out.println();
 	
 		System.out.println("OUTPUT BIND BY NAME WITH VALIDATION: ");
 		cur.clearBinds();
-		cur.defineOutputBind("numvar",10);
-		cur.defineOutputBind("stringvar",10);
-		cur.defineOutputBind("floatvar",10);
-		cur.defineOutputBind("dummyvar",10);
+		cur.defineOutputBindInteger("numvar");
+		cur.defineOutputBindString("stringvar",10);
+		cur.defineOutputBindDouble("floatvar");
+		cur.defineOutputBindString("dummyvar",10);
 		cur.validateBinds();
 		checkSuccess(cur.executeQuery(),1);
-		numvar=cur.getOutputBind("numvar");
-		stringvar=cur.getOutputBind("stringvar");
-		floatvar=cur.getOutputBind("floatvar");
-		checkSuccess(numvar,"1");
+		numvar=cur.getOutputBindInteger("numvar");
+		stringvar=cur.getOutputBindString("stringvar");
+		floatvar=cur.getOutputBindDouble("floatvar");
+		checkSuccess(numvar,1);
 		checkSuccess(stringvar,"hello");
-		checkSuccess(floatvar,"2.5");
+		checkSuccess(floatvar,2.5);
 		System.out.println();
 	
 		System.out.println("SELECT: ");
@@ -350,7 +388,7 @@ class oracle8i {
 		System.out.println();
 	
 		System.out.println("TOTAL ROWS: ");
-		checkSuccess(cur.totalRows(),-1);
+		checkSuccess(cur.totalRows(),0);
 		System.out.println();
 	
 		System.out.println("FIRST ROW INDEX: ");
@@ -471,9 +509,9 @@ class oracle8i {
 	
 		System.out.println("OUTPUT BIND: ");
 		cur.prepareQuery("begin :var1:='hello'; end;");
-		cur.defineOutputBind("var1",10);
+		cur.defineOutputBindString("var1",10);
 		checkSuccess(cur.executeQuery(),1);
-		checkSuccess(cur.getOutputBind("var1"),"hello");
+		checkSuccess(cur.getOutputBindString("var1"),"hello");
 		System.out.println();
 	
 		System.out.println("ARRAY SUBSTITUTIONS: ");
@@ -753,7 +791,7 @@ class oracle8i {
 	
 		System.out.println("COMMIT AND ROLLBACK: ");
 		SQLRConnection secondcon=new SQLRConnection(args[0],
-					Integer.parseInt(args[1]), 
+					(short)Integer.parseInt(args[1]), 
 					args[2],args[3],args[4],0,1);
 		SQLRCursor secondcur=new SQLRCursor(secondcon);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
@@ -779,9 +817,9 @@ class oracle8i {
 		cur.defineOutputBindClob("clobvar");
 		cur.defineOutputBindBlob("blobvar");
 		checkSuccess(cur.executeQuery(),1);
-		clobvar=cur.getOutputBind("clobvar");
+		clobvar=cur.getOutputBindClob("clobvar");
 		clobvarlength=cur.getOutputBindLength("clobvar");
-		blobvar=cur.getOutputBind("blobvar");
+		blobvar=cur.getOutputBindBlob("blobvar");
 		blobvarlength=cur.getOutputBindLength("blobvar");
 		checkSuccess(clobvar,"hello",5);
 		checkSuccess(clobvarlength,5);
@@ -840,7 +878,7 @@ class oracle8i {
 		cur.prepareQuery("begin select testclob into :clobbindval from testtable2; end;");
 		cur.defineOutputBindClob("clobbindval");
 		checkSuccess(cur.executeQuery(),1);
-		String	clobbindvar=cur.getOutputBind("clobbindval");
+		String	clobbindvar=cur.getOutputBindClob("clobbindval");
 		checkSuccess(cur.getOutputBindLength("clobbindval"),8*1024);
 		checkSuccess(clobval.toString(),clobbindvar);
 		cur.sendQuery("drop table testtable2");
@@ -864,10 +902,10 @@ class oracle8i {
 		query.append(testval.toString());
 		query.append("'; end;");
 		cur.prepareQuery(query.toString());
-		cur.defineOutputBind("bindval",4000);
+		cur.defineOutputBindString("bindval",4000);
 		checkSuccess(cur.executeQuery(),1);
 		checkSuccess(cur.getOutputBindLength("bindval"),4000);
-		checkSuccess(cur.getOutputBind("bindval"),testval.toString());
+		checkSuccess(cur.getOutputBindString("bindval"),testval.toString());
 		cur.sendQuery("drop table testtable2");
 		System.out.println();
 
