@@ -71,7 +71,7 @@ $cur->sendQuery("drop table testtable");
 
 # create a new table
 print("CREATE TEMPTABLE: \n");
-checkSuccess($cur->sendQuery("create table testdb.testtable (testtinyint tinyint, testsmallint smallint, testmediumint mediumint, testint int, testbigint bigint, testfloat float, testreal real, testdecimal decimal(1,1), testdate date, testtime time, testdatetime datetime, testyear year, testchar char(40), testtext text, testvarchar varchar(40), testtinytext tinytext, testmediumtext mediumtext, testlongtext longtext, testtimestamp timestamp)"),1);
+checkSuccess($cur->sendQuery("create table testdb.testtable (testtinyint tinyint, testsmallint smallint, testmediumint mediumint, testint int, testbigint bigint, testfloat float, testreal real, testdecimal decimal(2,1), testdate date, testtime time, testdatetime datetime, testyear year, testchar char(40), testtext text, testvarchar varchar(40), testtinytext tinytext, testmediumtext mediumtext, testlongtext longtext, testtimestamp timestamp)"),1);
 print("\n");
 
 print("INSERT: \n");
@@ -233,8 +233,8 @@ checkSuccessString($cur->getColumnType(12),"CHAR");
 checkSuccessString($cur->getColumnType(13),"BLOB");
 checkSuccessString($cur->getColumnType(14),"CHAR");
 checkSuccessString($cur->getColumnType(15),"TINYBLOB");
-checkSuccessString($cur->getColumnType(16),"BLOB");
-checkSuccessString($cur->getColumnType(17),"BLOB");
+checkSuccessString($cur->getColumnType(16),"MEDIUMBLOB");
+checkSuccessString($cur->getColumnType(17),"LONGBLOB");
 checkSuccessString($cur->getColumnType(18),"TIMESTAMP");
 checkSuccessString($cur->getColumnType("testtinyint"),"TINYINT");
 checkSuccessString($cur->getColumnType("testsmallint"),"SMALLINT");
@@ -252,8 +252,8 @@ checkSuccessString($cur->getColumnType("testchar"),"CHAR");
 checkSuccessString($cur->getColumnType("testtext"),"BLOB");
 checkSuccessString($cur->getColumnType("testvarchar"),"CHAR");
 checkSuccessString($cur->getColumnType("testtinytext"),"TINYBLOB");
-checkSuccessString($cur->getColumnType("testmediumtext"),"BLOB");
-checkSuccessString($cur->getColumnType("testlongtext"),"BLOB");
+checkSuccessString($cur->getColumnType("testmediumtext"),"MEDIUMBLOB");
+checkSuccessString($cur->getColumnType("testlongtext"),"LONGBLOB");
 checkSuccessString($cur->getColumnType("testtimestamp"),"TIMESTAMP");
 print("\n");
 
@@ -271,11 +271,11 @@ checkSuccess($cur->getColumnLength(9),3);
 checkSuccess($cur->getColumnLength(10),8);
 checkSuccess($cur->getColumnLength(11),1);
 checkSuccess($cur->getColumnLength(12),41);
-checkSuccess($cur->getColumnLength(13),65538);
+checkSuccess($cur->getColumnLength(13),65535);
 checkSuccess($cur->getColumnLength(14),41);
-checkSuccess($cur->getColumnLength(15),257);
-checkSuccess($cur->getColumnLength(16),16777218);
-checkSuccess($cur->getColumnLength(17),16777218);
+checkSuccess($cur->getColumnLength(15),255);
+checkSuccess($cur->getColumnLength(16),16777215);
+checkSuccess($cur->getColumnLength(17),2147483647);
 checkSuccess($cur->getColumnLength(18),4);
 checkSuccess($cur->getColumnLength("testtinyint"),1);
 checkSuccess($cur->getColumnLength("testsmallint"),2);
@@ -290,11 +290,11 @@ checkSuccess($cur->getColumnLength("testtime"),3);
 checkSuccess($cur->getColumnLength("testdatetime"),8);
 checkSuccess($cur->getColumnLength("testyear"),1);
 checkSuccess($cur->getColumnLength("testchar"),41);
-checkSuccess($cur->getColumnLength("testtext"),65538);
+checkSuccess($cur->getColumnLength("testtext"),65535);
 checkSuccess($cur->getColumnLength("testvarchar"),41);
-checkSuccess($cur->getColumnLength("testtinytext"),257);
-checkSuccess($cur->getColumnLength("testmediumtext"),16777218);
-checkSuccess($cur->getColumnLength("testlongtext"),16777218);
+checkSuccess($cur->getColumnLength("testtinytext"),255);
+checkSuccess($cur->getColumnLength("testmediumtext"),16777215);
+checkSuccess($cur->getColumnLength("testlongtext"),2147483647);
 checkSuccess($cur->getColumnLength("testtimestamp"),4);
 print("\n");
 
@@ -317,7 +317,7 @@ checkSuccess($cur->getLongest(14),8);
 checkSuccess($cur->getLongest(15),9);
 checkSuccess($cur->getLongest(16),11);
 checkSuccess($cur->getLongest(17),9);
-checkSuccess($cur->getLongest(18),14);
+checkSuccess($cur->getLongest(18),19);
 checkSuccess($cur->getLongest("testtinyint"),1);
 checkSuccess($cur->getLongest("testsmallint"),1);
 checkSuccess($cur->getLongest("testmediumint"),1);
@@ -336,7 +336,7 @@ checkSuccess($cur->getLongest("testvarchar"),8);
 checkSuccess($cur->getLongest("testtinytext"),9);
 checkSuccess($cur->getLongest("testmediumtext"),11);
 checkSuccess($cur->getLongest("testlongtext"),9);
-checkSuccess($cur->getLongest("testtimestamp"),14);
+checkSuccess($cur->getLongest("testtimestamp"),19);
 print("\n");
 
 print("ROW COUNT: \n");
