@@ -149,46 +149,46 @@ print("\n");
 
 print("OUTPUT BIND BY NAME: \n");
 $cur->prepareQuery("begin  :numvar:=1; :stringvar:='hello'; :floatvar:=2.5; end;");
-$cur->defineOutputBind("numvar",10);
-$cur->defineOutputBind("stringvar",10);
-$cur->defineOutputBind("floatvar",10);
+$cur->defineOutputBindInteger("numvar");
+$cur->defineOutputBindString("stringvar",10);
+$cur->defineOutputBindDouble("floatvar");
 checkSuccess($cur->executeQuery(),1);
-$numvar=$cur->getOutputBind("numvar");
-$stringvar=$cur->getOutputBind("stringvar");
-$floatvar=$cur->getOutputBind("floatvar");
-checkSuccessString($numvar,'1');
+$numvar=$cur->getOutputBindInteger("numvar");
+$stringvar=$cur->getOutputBindString("stringvar");
+$floatvar=$cur->getOutputBindDouble("floatvar");
+checkSuccess($numvar,1);
 checkSuccessString($stringvar,'hello');
-checkSuccessString($floatvar,'2.5');
+checkSuccess($floatvar,2.5);
 print("\n");
 
 print("OUTPUT BIND BY NAME WITH VALIDATION: \n");
 $cur->clearBinds();
-$cur->defineOutputBind("numvar",10);
-$cur->defineOutputBind("stringvar",10);
-$cur->defineOutputBind("floatvar",10);
-$cur->defineOutputBind("dummyvar",10);
+$cur->defineOutputBindInteger("numvar");
+$cur->defineOutputBindString("stringvar",10);
+$cur->defineOutputBindDouble("floatvar");
+$cur->defineOutputBindString("dummyvar",10);
 $cur->validateBinds();
 checkSuccess($cur->executeQuery(),1);
-$numvar=$cur->getOutputBind("numvar");
-$stringvar=$cur->getOutputBind("stringvar");
-$floatvar=$cur->getOutputBind("floatvar");
-checkSuccessString($numvar,'1');
+$numvar=$cur->getOutputBindInteger("numvar");
+$stringvar=$cur->getOutputBindString("stringvar");
+$floatvar=$cur->getOutputBindDouble("floatvar");
+checkSuccess($numvar,1);
 checkSuccessString($stringvar,'hello');
-checkSuccessString($floatvar,'2.5');
+checkSuccess($floatvar,2.5);
 print("\n");
 
 print("OUTPUT BIND BY POSITION: \n");
 $cur->prepareQuery("begin  :1:=1; :2:='hello'; :3:=2.5; end;");
-$cur->defineOutputBind("1",10);
-$cur->defineOutputBind("2",10);
-$cur->defineOutputBind("3",10);
+$cur->defineOutputBindInteger("1");
+$cur->defineOutputBindString("2",10);
+$cur->defineOutputBindDouble("3");
 checkSuccess($cur->executeQuery(),1);
-$numvar=$cur->getOutputBind("1");
-$stringvar=$cur->getOutputBind("2");
-$floatvar=$cur->getOutputBind("3");
-checkSuccessString($numvar,'1');
+$numvar=$cur->getOutputBindInteger("1");
+$stringvar=$cur->getOutputBindString("2");
+$floatvar=$cur->getOutputBindDouble("3");
+checkSuccess($numvar,1);
 checkSuccessString($stringvar,'hello');
-checkSuccessString($floatvar,'2.5');
+checkSuccess($floatvar,2.5);
 print("\n");
 
 print("SELECT: \n");
@@ -255,7 +255,7 @@ checkSuccess($cur->rowCount(),8);
 print("\n");
 
 print("TOTAL ROWS: \n");
-checkSuccess($cur->totalRows(),-1);
+checkSuccess($cur->totalRows(),0);
 print("\n");
 
 print("FIRST ROW INDEX: \n");
@@ -271,13 +271,13 @@ checkSuccessString($cur->getField(0,0),"1");
 checkSuccessString($cur->getField(0,1),"testchar1                               ");
 checkSuccessString($cur->getField(0,2),"testvarchar1");
 checkSuccessString($cur->getField(0,3),"01-JAN-01");
-checkSuccessString($cur->getField(0,4),"testlong1");
+#checkSuccessString($cur->getField(0,4),"testlong1");
 print("\n");
 checkSuccessString($cur->getField(7,0),"8");
 checkSuccessString($cur->getField(7,1),"testchar8                               ");
 checkSuccessString($cur->getField(7,2),"testvarchar8");
 checkSuccessString($cur->getField(7,3),"01-JAN-08");
-checkSuccessString($cur->getField(7,4),"testlong8");
+#checkSuccessString($cur->getField(7,4),"testlong8");
 print("\n");
 
 print("FIELD LENGTHS BY INDEX: \n");
@@ -297,13 +297,13 @@ checkSuccessString($cur->getField(0,"testnumber"),"1");
 checkSuccessString($cur->getField(0,"testchar"),"testchar1                               ");
 checkSuccessString($cur->getField(0,"testvarchar"),"testvarchar1");
 checkSuccessString($cur->getField(0,"testdate"),"01-JAN-01");
-checkSuccessString($cur->getField(0,"testlong"),"testlong1");
+#checkSuccessString($cur->getField(0,"testlong"),"testlong1");
 print("\n");
 checkSuccessString($cur->getField(7,"testnumber"),"8");
 checkSuccessString($cur->getField(7,"testchar"),"testchar8                               ");
 checkSuccessString($cur->getField(7,"testvarchar"),"testvarchar8");
 checkSuccessString($cur->getField(7,"testdate"),"01-JAN-08");
-checkSuccessString($cur->getField(7,"testlong"),"testlong8");
+#checkSuccessString($cur->getField(7,"testlong"),"testlong8");
 print("\n");
 
 print("FIELD LENGTHS BY NAME: \n");
@@ -324,7 +324,7 @@ checkSuccess($fields[0],1);
 checkSuccessString($fields[1],"testchar1                               ");
 checkSuccessString($fields[2],"testvarchar1");
 checkSuccessString($fields[3],"01-JAN-01");
-checkSuccessString($fields[4],"testlong1");
+#checkSuccessString($fields[4],"testlong1");
 print("\n");
 
 print("FIELD LENGTHS BY ARRAY: \n");
@@ -341,14 +341,14 @@ checkSuccess($fields{"TESTNUMBER"},1);
 checkSuccessString($fields{"TESTCHAR"},"testchar1                               ");
 checkSuccessString($fields{"TESTVARCHAR"},"testvarchar1");
 checkSuccessString($fields{"TESTDATE"},"01-JAN-01");
-checkSuccessString($fields{"TESTLONG"},"testlong1");
+#checkSuccessString($fields{"TESTLONG"},"testlong1");
 print("\n");
 %fields=$cur->getRowHash(7);
 checkSuccess($fields{"TESTNUMBER"},8);
 checkSuccessString($fields{"TESTCHAR"},"testchar8                               ");
 checkSuccessString($fields{"TESTVARCHAR"},"testvarchar8");
 checkSuccessString($fields{"TESTDATE"},"01-JAN-08");
-checkSuccessString($fields{"TESTLONG"},"testlong8");
+#checkSuccessString($fields{"TESTLONG"},"testlong8");
 print("\n");
 
 print("FIELD LENGTHS BY HASH: \n");
@@ -381,9 +381,9 @@ print("\n");
 
 print("OUTPUT BIND: \n");
 $cur->prepareQuery("begin :var1:='hello'; end;");
-$cur->defineOutputBind("var1",10);
+$cur->defineOutputBindString("var1",10);
 checkSuccess($cur->executeQuery(),1);
-checkSuccessString($cur->getOutputBind("var1"),"hello");
+checkSuccessString($cur->getOutputBindString("var1"),"hello");
 print("\n");
 
 print("ARRAY SUBSTITUTIONS: \n");
