@@ -4,8 +4,8 @@
 # See the file COPYING for more information.
 
 
-use Firstworks::SQLRConnection;
-use Firstworks::SQLRCursor;
+use SQLRelay::Connection;
+use SQLRelay::Cursor;
 
 sub checkUndef {
 
@@ -54,9 +54,9 @@ if ($#ARGV+1<5) {
 
 
 # instantiation
-$con=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1],
+$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
 					$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur=Firstworks::SQLRCursor->new($con);
+$cur=SQLRelay::Cursor->new($con);
 
 print("IDENTIFY: \n");
 checkSuccessString($con->identify(),"postgresql");
@@ -91,6 +91,7 @@ print("\n");
 
 print("BIND BY NAME: \n");
 $cur->prepareQuery("insert into testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8)");
+checkSuccess($cur->countBindVariables(),8);
 $cur->inputBind("var1",5);
 $cur->inputBind("var2",5.5,4,2);
 $cur->inputBind("var3",5.5,4,2);
@@ -666,9 +667,9 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1], 
+$secondcon=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
 		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$secondcur=Firstworks::SQLRCursor->new($secondcon);
+$secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"0");
 checkSuccess($con->commit(),1);
@@ -703,6 +704,26 @@ print("\n");
 # drop existing table
 $cur->sendQuery("drop table testtable");
 
+print("STORED PROCEDURES: \n");
+$cur->sendQuery("drop function testfunc(int)");
+checkSuccess($cur->sendQuery("create function testfunc(int) returns int as ' begin return \$1; end;' language plpgsql"),1);
+$cur->prepareQuery("select * from testfunc(:int)");
+$cur->inputBind("int",5);
+checkSuccess($cur->executeQuery(),1);
+checkSuccess($cur->getField(0,0),"5");
+$cur->sendQuery("drop function testfunc(int)");
+
+$cur->sendQuery("drop function testfunc(int,char(20))");
+checkSuccess($cur->sendQuery("create function testfunc(int, char(20)) returns record as ' declare output record; begin select \$1,\$2 into output; return output; end;' language plpgsql"),1);
+$cur->prepareQuery("select * from testfunc(:int,:char) as (col1 int, col2 char(20))");
+$cur->inputBind("int",5);
+$cur->inputBind("char","hello");
+checkSuccess($cur->executeQuery(),1);
+checkSuccess($cur->getField(0,0),"5");
+checkSuccess($cur->getField(0,1),"hello");
+$cur->sendQuery("drop function testfunc(int,char(20))");
+print("\n");
+
 # invalid queries...
 print("INVALID QUERIES: \n");
 checkSuccess($cur->sendQuery("select * from testtable order by testint"),0);
