@@ -4,8 +4,8 @@
 # See the file COPYING for more information.
 
 
-use Firstworks::SQLRConnection;
-use Firstworks::SQLRCursor;
+use SQLRelay::Connection;
+use SQLRelay::Cursor;
 
 
 # usage...
@@ -16,20 +16,20 @@ if ($#ARGV+1<5) {
 
 
 # instantiation
-$con1=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1], 
+$con1=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
 				$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur1=Firstworks::SQLRCursor->new($con1);
+$cur1=SQLRelay::Cursor->new($con1);
 $cur1->sendQuery("select 1 from dual");
 
 
-$con2=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1], 
+$con2=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
 				$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur2=Firstworks::SQLRCursor->new($con2);
+$cur2=SQLRelay::Cursor->new($con2);
 $cur2->sendQuery("select 1 from dual");
 
 
 
-$con3=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1], 
+$con3=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
 				$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur3=Firstworks::SQLRCursor->new($con3);
+$cur3=SQLRelay::Cursor->new($con3);
 $cur3->sendQuery("select 1 from dual");
