@@ -116,46 +116,46 @@ function checkSuccess($value,$success) {
 
 	echo("OUTPUT BIND BY NAME: \n");
 	sqlrcur_prepareQuery($cur,"begin  :numvar:=1; :stringvar:='hello'; :floatvar:=2.5; end;");
-	sqlrcur_defineOutputBind($cur,"numvar",10);
-	sqlrcur_defineOutputBind($cur,"stringvar",10);
-	sqlrcur_defineOutputBind($cur,"floatvar",10);
+	sqlrcur_defineOutputBindInteger($cur,"numvar");
+	sqlrcur_defineOutputBindString($cur,"stringvar",10);
+	sqlrcur_defineOutputBindDouble($cur,"floatvar");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	$numvar=sqlrcur_getOutputBind($cur,"numvar");
-	$stringvar=sqlrcur_getOutputBind($cur,"stringvar");
-	$floatvar=sqlrcur_getOutputBind($cur,"floatvar");
-	checkSuccess($numvar,"1");
+	$numvar=sqlrcur_getOutputBindInteger($cur,"numvar");
+	$stringvar=sqlrcur_getOutputBindString($cur,"stringvar");
+	$floatvar=sqlrcur_getOutputBindDouble($cur,"floatvar");
+	checkSuccess($numvar,1);
 	checkSuccess($stringvar,"hello");
-	checkSuccess($floatvar,"2.5");
+	checkSuccess($floatvar,2.5);
 	echo("\n");
 
 	echo("OUTPUT BIND BY NAME WITH VALIDATION: \n");
 	sqlrcur_clearBinds($cur);
-	sqlrcur_defineOutputBind($cur,"numvar",10);
-	sqlrcur_defineOutputBind($cur,"stringvar",10);
-	sqlrcur_defineOutputBind($cur,"floatvar",10);
-	sqlrcur_defineOutputBind($cur,"dummyvar",10);
+	sqlrcur_defineOutputBindInteger($cur,"numvar");
+	sqlrcur_defineOutputBindString($cur,"stringvar",10);
+	sqlrcur_defineOutputBindDouble($cur,"floatvar");
+	sqlrcur_defineOutputBindString($cur,"dummyvar",10);
 	sqlrcur_validateBinds($cur);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	$numvar=sqlrcur_getOutputBind($cur,"numvar");
-	$stringvar=sqlrcur_getOutputBind($cur,"stringvar");
-	$floatvar=sqlrcur_getOutputBind($cur,"floatvar");
-	checkSuccess($numvar,"1");
+	$numvar=sqlrcur_getOutputBindInteger($cur,"numvar");
+	$stringvar=sqlrcur_getOutputBindString($cur,"stringvar");
+	$floatvar=sqlrcur_getOutputBindDouble($cur,"floatvar");
+	checkSuccess($numvar,1);
 	checkSuccess($stringvar,"hello");
-	checkSuccess($floatvar,"2.5");
+	checkSuccess($floatvar,2.5);
 	echo("\n");
 
 	echo("OUTPUT BIND BY POSITION: \n");
 	sqlrcur_prepareQuery($cur,"begin  :1:=1; :2:='hello'; :3:=2.5; end;");
-	sqlrcur_defineOutputBind($cur,"1",10);
-	sqlrcur_defineOutputBind($cur,"2",10);
-	sqlrcur_defineOutputBind($cur,"3",10);
+	sqlrcur_defineOutputBindInteger($cur,"1");
+	sqlrcur_defineOutputBindString($cur,"2",10);
+	sqlrcur_defineOutputBindDouble($cur,"3");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	$numvar=sqlrcur_getOutputBind($cur,"1");
-	$stringvar=sqlrcur_getOutputBind($cur,"2");
-	$floatvar=sqlrcur_getOutputBind($cur,"3");
-	checkSuccess($numvar,"1");
+	$numvar=sqlrcur_getOutputBindInteger($cur,"1");
+	$stringvar=sqlrcur_getOutputBindString($cur,"2");
+	$floatvar=sqlrcur_getOutputBindDouble($cur,"3");
+	checkSuccess($numvar,1);
 	checkSuccess($stringvar,"hello");
-	checkSuccess($floatvar,"2.5");
+	checkSuccess($floatvar,2.5);
 	echo("\n");
 
 	echo("SELECT: \n");
@@ -222,7 +222,7 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("TOTAL ROWS: \n");
-	checkSuccess(sqlrcur_totalRows($cur),-1);
+	checkSuccess(sqlrcur_totalRows($cur),0);
 	echo("\n");
 
 	echo("FIRST ROW INDEX: \n");
@@ -357,9 +357,9 @@ function checkSuccess($value,$success) {
 
 	echo("OUTPUT BIND: \n");
 	sqlrcur_prepareQuery($cur,"begin :var1:='hello'; end;");
-	sqlrcur_defineOutputBind($cur,"var1",10);
+	sqlrcur_defineOutputBindString($cur,"var1",10);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	checkSuccess(sqlrcur_getOutputBind($cur,"var1"),"hello");
+	checkSuccess(sqlrcur_getOutputBindString($cur,"var1"),"hello");
 	echo("\n");
 
 	echo("ARRAY SUBSTITUTIONS: \n");
