@@ -21,7 +21,7 @@ require_once 'DB.php';
 	$socket=$_REQUEST["socket"];
 	$user=$_REQUEST["user"];
 	$password=$_REQUEST["password"];
-	$dsn = "sqlrelay://$user:$password@$host:$port/$db_name";
+	$dsn = "sqlrelay://$user:$password@$host:$port/";
 
 	# instantiation
 	$db = DB::connect($dsn);
@@ -112,11 +112,10 @@ require_once 'DB.php';
 			"testlong" => NULL);
 	checkSuccess($db,$db->autoExecute("testtable",$bindvars,
 					DB_AUTOQUERY_INSERT),DB_OK);
-
-	echo("SELECT: \n");
-	$res=$db->query("select * from testtable order by testnumber");
 	echo("\n");
 
+	$res=$db->query("select * from testtable order by testnumber");
+
 	echo("COLUMN COUNT: \n");
 	checkSuccess($db,$res->numCols(),5);
 	echo("\n");
@@ -459,6 +458,15 @@ require_once 'DB.php';
 	checkSuccess($db,$db->dropSequence("mysequence"),DB_OK);
 	echo("\n");
 
+	echo("?'s INSIDE QUOTES: \n");
+	$sth=$db->prepare("select '?',':help',? from dual");
+	$res=$db->execute($sth,array(1));
+	$row=$res->fetchRow(DB_FETCHMODE_ORDERED);
+	checkSuccess($db,$row[0],"?");
+	checkSuccess($db,$row[1],":help");
+	checkSuccess($db,$row[2],"1");
+	echo("\n");
+
 	# drop existing table
 	$db->query("drop table testtable");
 
