@@ -134,46 +134,46 @@ def main():
 
 	print "OUTPUT BIND BY NAME: "
 	cur.prepareQuery("begin  :numvar:=1; :stringvar:='hello'; :floatvar:=2.5; end;")
-	cur.defineOutputBind("numvar",10)
-	cur.defineOutputBind("stringvar",10)
-	cur.defineOutputBind("floatvar",10)
+	cur.defineOutputBindInteger("numvar")
+	cur.defineOutputBindString("stringvar",10)
+	cur.defineOutputBindDouble("floatvar")
 	checkSuccess(cur.executeQuery(),1)
-	numvar=cur.getOutputBind("numvar")
-	stringvar=cur.getOutputBind("stringvar")
-	floatvar=cur.getOutputBind("floatvar")
-	checkSuccess(numvar,'1')
+	numvar=cur.getOutputBindInteger("numvar")
+	stringvar=cur.getOutputBindString("stringvar")
+	floatvar=cur.getOutputBindDouble("floatvar")
+	checkSuccess(numvar,1)
 	checkSuccess(stringvar,'hello')
-	checkSuccess(floatvar,'2.5')
+	checkSuccess(floatvar,2.5)
 	print
 
 	print "OUTPUT BIND BY NAME: "
 	cur.clearBinds()
-	cur.defineOutputBind("1",10)
-	cur.defineOutputBind("2",10)
-	cur.defineOutputBind("3",10)
+	cur.defineOutputBindInteger("1")
+	cur.defineOutputBindString("2",10)
+	cur.defineOutputBindDouble("3")
 	checkSuccess(cur.executeQuery(),1)
-	numvar=cur.getOutputBind("1")
-	stringvar=cur.getOutputBind("2")
-	floatvar=cur.getOutputBind("3")
-	checkSuccess(numvar,'1')
+	numvar=cur.getOutputBindInteger("1")
+	stringvar=cur.getOutputBindString("2")
+	floatvar=cur.getOutputBindDouble("3")
+	checkSuccess(numvar,1)
 	checkSuccess(stringvar,'hello')
-	checkSuccess(floatvar,'2.5')
+	checkSuccess(floatvar,2.5)
 	print
 
 	print "OUTPUT BIND BY NAME WITH VALIDATION: "
 	cur.clearBinds()
-	cur.defineOutputBind("numvar",10)
-	cur.defineOutputBind("stringvar",10)
-	cur.defineOutputBind("floatvar",10)
-	cur.defineOutputBind("dummyvar",10)
+	cur.defineOutputBindInteger("numvar")
+	cur.defineOutputBindString("stringvar",10)
+	cur.defineOutputBindDouble("floatvar")
+	cur.defineOutputBindString("dummyvar",10)
 	cur.validateBinds()
 	checkSuccess(cur.executeQuery(),1)
-	numvar=cur.getOutputBind("numvar")
-	stringvar=cur.getOutputBind("stringvar")
-	floatvar=cur.getOutputBind("floatvar")
-	checkSuccess(numvar,'1')
+	numvar=cur.getOutputBindInteger("numvar")
+	stringvar=cur.getOutputBindString("stringvar")
+	floatvar=cur.getOutputBindDouble("floatvar")
+	checkSuccess(numvar,1)
 	checkSuccess(stringvar,'hello')
-	checkSuccess(floatvar,'2.5')
+	checkSuccess(floatvar,2.5)
 	print
 
 	print "SELECT: "
@@ -258,7 +258,7 @@ def main():
 	print
 
 	print "TOTAL ROWS: "
-	checkSuccess(cur.totalRows(),-1)
+	checkSuccess(cur.totalRows(),0)
 	print
 
 	print "FIRST ROW INDEX: "
@@ -420,9 +420,9 @@ def main():
 
 	print "OUTPUT BIND: "
 	cur.prepareQuery("begin :var1:='hello'; end;")
-	cur.defineOutputBind("var1",10)
+	cur.defineOutputBindString("var1",10)
 	checkSuccess(cur.executeQuery(),1)
-	checkSuccess(cur.getOutputBind("var1"),"hello")
+	checkSuccess(cur.getOutputBindString("var1"),"hello")
 	print
 
 	print "ARRAY SUBSTITUTIONS: "
@@ -746,9 +746,9 @@ def main():
 	cur.defineOutputBindClob("clobvar")
 	cur.defineOutputBindBlob("blobvar")
 	checkSuccess(cur.executeQuery(),1)
-	clobvar=cur.getOutputBind("clobvar")
+	clobvar=cur.getOutputBindClob("clobvar")
 	clobvarlength=cur.getOutputBindLength("clobvar")
-	blobvar=cur.getOutputBind("blobvar")
+	blobvar=cur.getOutputBindBlob("blobvar")
 	blobvarlength=cur.getOutputBindLength("blobvar")
 	checkSuccess(clobvar,"hello")
 	checkSuccess(clobvarlength,5)
@@ -806,7 +806,7 @@ def main():
 	cur.prepareQuery("begin select testclob into :clobbindval from testtable2; end;")
 	cur.defineOutputBindClob("clobbindval")
 	checkSuccess(cur.executeQuery(),1)
-	clobbindvar=cur.getOutputBind("clobbindval")
+	clobbindvar=cur.getOutputBindClob("clobbindval")
 	checkSuccess(cur.getOutputBindLength("clobbindval"),8*1024)
 	checkSuccess(clobval,clobbindvar)
 	cur.sendQuery("drop table testtable2")
